@@ -1,5 +1,3 @@
-/* $Id: prockernel.h,v 1.27 2006/04/18 20:17:25 gpoo Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -75,10 +73,10 @@ void glibtop_get_proc_kernel(glibtop_proc_kernel *buf, pid_t pid);
 void glibtop_get_proc_kernel_l (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_KERNEL
-void glibtop_init_proc_kernel_p (glibtop *server);
+void _glibtop_init_proc_kernel_p (glibtop *server);
 void glibtop_get_proc_kernel_p (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
 #else
-void glibtop_init_proc_kernel_s (glibtop *server);
+void _glibtop_init_proc_kernel_s (glibtop *server);
 void glibtop_get_proc_kernel_s (glibtop *server, glibtop_proc_kernel *buf, pid_t pid);
 #endif
 
