@@ -1,5 +1,3 @@
-/* $Id: sysinfo.h,v 1.13 2004/06/13 08:19:59 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -50,15 +48,15 @@ struct _glibtop_entry
 
 struct _glibtop_sysinfo
 {
-	guint64	flags, ncpu;
+	guint64	flags;
+	guint64 ncpu;
 	glibtop_entry cpuinfo [GLIBTOP_NCPU];
 };
 
-#define glibtop_get_sysinfo()	glibtop_get_sysinfo_s(glibtop_global_server)
-
 #define glibtop_get_sysinfo_r	glibtop_get_sysinfo_s
 
 const glibtop_sysinfo *glibtop_get_sysinfo_s (glibtop *server);
+const glibtop_sysinfo *glibtop_get_sysinfo (void);
 
 G_END_DECLS
 
