@@ -1,5 +1,3 @@
-/* $Id: glibtop_server.h,v 1.2 2003/10/19 16:54:39 carlos Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -24,12 +22,12 @@
 #ifndef __GLIBTOP_SERVER_H__
 #define __GLIBTOP_SERVER_H__
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_SUID_CPU		(1 << GLIBTOP_SYSDEPS_CPU)
 #define GLIBTOP_SUID_MEM		0
 #define GLIBTOP_SUID_SWAP		0
-#define GLIBTOP_SUID_UPTIME		(1 << GLIBTOP_SYSDEPS_UPTIME)
+#define GLIBTOP_SUID_UPTIME		0
 #define GLIBTOP_SUID_LOADAVG		(1 << GLIBTOP_SYSDEPS_LOADAVG)
 #define GLIBTOP_SUID_SHM_LIMITS		(1 << GLIBTOP_SYSDEPS_SHM_LIMITS)
 #define GLIBTOP_SUID_MSG_LIMITS		(1 << GLIBTOP_SYSDEPS_MSG_LIMITS)
@@ -45,8 +43,9 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SUID_PROC_ARGS		0
 #define GLIBTOP_SUID_PROC_MAP		0
 #define GLIBTOP_SUID_NETLOAD		(1 << GLIBTOP_SYSDEPS_NETLOAD)
+#define GLIBTOP_SUID_NETLIST		0
 #define GLIBTOP_SUID_PPP		0
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
