@@ -543,6 +543,7 @@ static gboolean ignore_mount_entry(const struct mount_entry *me)
 		"ctfs",
 		"devfs",
 		"devpts",
+		"fusectl",
 		"linprocfs",
 		"mfs",
 		"mntfs",
@@ -553,6 +554,8 @@ static gboolean ignore_mount_entry(const struct mount_entry *me)
 		"openpromfs",
 		"proc",
 		"procfs",
+		"rpc_pipefs",
+		"securityfs",
 		"supermount",
 		"sysfs",
 		"tmpfs",
